/**
 * Klasa Resenje koristi se za pamcenje pronadjenog puta.
 * 
 * Polje Polja se koristi za pamcenje svih polja na putu.
 * 
 * Polje nepromenljivaListaPolja je dodata da se omoguci
 * pristup poljima resenja "spolja" (za proveru kvaliteta puta na primer), 
 * ali tako da ne moze da se utice na sam sadrzaj te liste.
 */
import java.util.ArrayList;
import java.util.List;
import java.util.Collections;

public class Resenje implements Cloneable {
	private ArrayList<Polje> polja;
	private List<Polje> nepromenljivaListaPolja;

	Resenje() {
		polja = new ArrayList<Polje>();
		nepromenljivaListaPolja = Collections.unmodifiableList(polja);
	}

	// Dodaje pulje u resenje
	public void dodaj(int x, int y, int v) {
		polja.add(new Polje(x, y, v));
	}

	// Izbacuje polje iz resenja
	public void izbaciKraj() {
		if (getLength() > 0) {
			polja.remove(getLength() - 1);
		} else {
			System.err.println("greska: resenje je vec prazno");
		}
	}

	// Stampa resenje
	public void stampaj() {
		System.out.println(getLength());
		for (int i = 0; i < getLength(); i++)
			System.out.println(polja.get(i));
	}

	// Vraca duzinu resenja
	public int getLength() {
		return polja.size();
	}

	// Vraca i-to polje na putu. Ne koristi se u ovoj verziji zadatka.
	// Moze se koristiti za proveru kvaliteta resenja
	public Polje getPolje(int i) {
		return polja.get(i);
	}

	// Vraca sva polja na putu. Ne koristi se u ovoj verziji zadatka.
	// Moze se koristiti za proveru kvaliteta resenja
	public List<Polje> getPolja() {
		return nepromenljivaListaPolja;
	}

	// Kreira klon od resenja
	@Override
	public Resenje clone() {
		Resenje rez = new Resenje();
		for (Polje p : polja) {
			rez.dodaj(p.getX(), p.getY(), p.getV());
		}
		return rez;
	}

	// Vraca vrednost puta
	// Vrednost se definise kao zbir svih vrednosti polja na putu
	public int getVrednost() {
		int rez = 0;
		for (Polje p : polja) {
			rez = rez + p.getV();
		}
		return rez;
	}
}
